@@ -11,6 +11,7 @@ from lxml.etree import XMLSyntaxError
 from pyppeteer.errors import PageError
 from pyppeteer.errors import TimeoutError as tout
 from requests.exceptions import ConnectionError
+from requests.exceptions import ReadTimeout as rtout
 from requests_html import AsyncHTMLSession
 from requests_html import HTMLSession
 
@@ -22,6 +23,7 @@ from .files import write_txt_to_file_async
 nest_asyncio.apply()
 
 cte = Const()
+ases = AsyncHTMLSession()
 
 def download_chromium_if_not_installed() :
     """download chromium if not installed"""
@@ -46,64 +48,34 @@ async def get_and_render_by_requests_html_async(url ,
                                                 verify = True ,
                                                 get_timeout = None ,
                                                 render_timeout = None) :
-    a = AsyncHTMLSession()
-    await a.close()
-
-    r = await a.get(url ,
-                    headers = headers ,
-                    params = params ,
-                    verify = verify ,
-                    timeout = get_timeout)
-
-    await a.close()
-
+    r = await ases.get(url ,
+                       headers = headers ,
+                       params = params ,
+                       verify = verify ,
+                       timeout = get_timeout)
     try :
         await r.html.arender(timeout = render_timeout)
         return RGetAndRender(status = r.status_code ,
                              headers = r.headers ,
                              html = r.html.html ,
                              err = None)
-    except (XMLSyntaxError , tout , PageError , ConnectionError) as e :
+    except (XMLSyntaxError , tout , PageError , ConnectionError , rtout) as e :
         print(e)
         return RGetAndRender(status = r.status_code ,
                              headers = r.headers ,
                              html = None ,
                              err = e)
 
-async def get_a_rendered_html_and_save_async(url ,
-                                             fp ,
-                                             headers = cte.headers ,
-                                             params = None ,
-                                             verify = True ,
-                                             get_timeout = None ,
-                                             render_timeout = None) :
-    fu = get_and_render_by_requests_html_async
-    o = await fu(url ,
-                 headers = headers ,
-                 params = params ,
-                 verify = verify ,
-                 get_timeout = get_timeout ,
-                 render_timeout = render_timeout)
-
+async def get_a_rendered_html_and_save_async(url , fp , **kwargs) :
+    fu = partial(get_and_render_by_requests_html_async , **kwargs)
+    o = await fu(url)
     outer_html = o.html
     if outer_html :
         await write_txt_to_file_async(outer_html , fp)
-
     return o
 
-async def get_rendered_htmls_and_save_async(urls ,
-                                            fps ,
-                                            headers = cte.headers ,
-                                            params = None ,
-                                            verify = True ,
-                                            get_timeout = None ,
-                                            render_timeout = None) :
-    fu = partial(get_a_rendered_html_and_save_async ,
-                 headers = headers ,
-                 params = params ,
-                 verify = verify ,
-                 get_timeout = get_timeout ,
-                 render_timeout = render_timeout)
+async def get_rendered_htmls_and_save_async(urls , fps , **kwargs) :
+    fu = partial(get_a_rendered_html_and_save_async , **kwargs)
     co_tasks = [fu(x , y) for x , y in zip(urls , fps)]
     return await asyncio.gather(*co_tasks)
 
